summaryrefslogtreecommitdiffstats
path: root/sys/dev/ciss
diff options
context:
space:
mode:
Diffstat (limited to 'sys/dev/ciss')
-rw-r--r--sys/dev/ciss/ciss.c27
1 files changed, 4 insertions, 23 deletions
diff --git a/sys/dev/ciss/ciss.c b/sys/dev/ciss/ciss.c
index 880e03a..6e328e6 100644
--- a/sys/dev/ciss/ciss.c
+++ b/sys/dev/ciss/ciss.c
@@ -2613,35 +2613,16 @@ ciss_cam_emulate(struct ciss_softc *sc, struct ccb_scsiio *csio)
*(u_int8_t *)csio->cdb_io.cdb_ptr : csio->cdb_io.cdb_bytes[0];
/*
* Handle requests for volumes that don't exist. A selection timeout
* is slightly better than an illegal request. Other errors might be
* better.
*/
- if (sc->ciss_logical[bus][target].cl_status == CISS_LD_NONEXISTENT) {
+ if (sc->ciss_logical[bus][target].cl_status != CISS_LD_ONLINE) {
csio->ccb_h.status = CAM_SEL_TIMEOUT;
xpt_done((union ccb *)csio);
return(1);
}
- /*
- * Handle requests for volumes that exist but are offline.
- *
- * I/O operations should fail, everything else should work.
- */
- if (sc->ciss_logical[bus][target].cl_status == CISS_LD_OFFLINE) {
- switch(opcode) {
- case READ_6:
- case READ_10:
- case READ_12:
- case WRITE_6:
- case WRITE_10:
- case WRITE_12:
- csio->ccb_h.status = CAM_SEL_TIMEOUT;
- xpt_done((union ccb *)csio);
- return(1);
- }
- }
-
/* if we have to fake Synchronise Cache */
if (sc->ciss_flags & CISS_FLAG_FAKE_SYNCH) {
/*
@@ -2613,35 +2613,16 @@ ciss_cam_emulate(struct ciss_softc *sc, struct ccb_scsiio *csio)
*(u_int8_t *)csio->cdb_io.cdb_ptr : csio->cdb_io.cdb_bytes[0];
/*
- * Handle requests for volumes that don't exist. A selection timeout
- * is slightly better than an illegal request. Other errors might be
- * better.
+ * Handle requests for volumes that don't exist or are not online.
+ * A selection timeout is slightly better than an illegal request.
+ * Other errors might be better.
*/
OpenPOWER on IntegriCloud